% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aha_2021_conference_ptp.R
\name{calculate_aha_2021_ptp}
\alias{calculate_aha_2021_ptp}
\title{Calculate AHA/ACC 2021 PTP for obstructive CAD}
\usage{
calculate_aha_2021_ptp(
  age,
  sex,
  have_dyspnoea,
  have_chest_pain,
  output = c("grouping", "numeric", "percentage")
)
}
\arguments{
\item{age}{Input integer value to indicate the age of the patient.}

\item{sex}{Input characters (female, male) to indicate the sex of the patient.
\itemize{
  \item female
  \item male
}}

\item{have_dyspnoea}{Input characters (no, yes) to indicate if the patient
only has dyspnoea symptoms.
\itemize{
  \item no stands for not having dyspnoea symptoms.
  \item yes stands for having dyspnoea symptoms.
}}

\item{have_chest_pain}{Input characters (no, yes) to indicate if the patient
has chest pain.
\itemize{
  \item no stands for not having dyspnoea symptoms.
  \item yes stands for having dyspnoea symptoms.
}}

\item{output}{Input text to indicate the how pre-test
probability results be expressed
Default: c("grouping", "numeric", "percentage")
\itemize{
  \item grouping means the PTP will be expressed as Low, Intermediate and High.
  \itemize{
     \item very low if PTP is less than 5\%.
     \item low if PTP is in between 5\% to 15\%.
     \item intermediate if PTP is in between 15\% to 50\%.
     \item high if PTP is more than 50\%.
  }
  \item numeric means the PTP will be expressed as an integer probability (0-100).
  \item percentage means the PTP will be expressed as percentage text (0-100\%).
}}
}
\value{
An integer, percentage or category representing the patient's PTP for obstructive CAD
based on the AHA/ACC 2021 guidelines.
See parameter option \code{output} for more information.
}
\description{
This function returns a patient's
pre-test Probability (PTP) of obstructive
coronary artery disease (CAD) based on the
American Heart Association/American College of Cardiology (AHA/ACC) 2021 guidelines.
}
\details{
The predictive model used to create the guidelines are based on
patients from European countries with low cardiovascular disease (CVD) risk.

If the patient has both dyspnoea and a particular
chest pain type (typical, atypical, nonanginal),
The chest pain type will take precedence over dyspnoea
}
\examples{
# 35 year old female with chest pain
calculate_aha_2021_ptp(
    age = 35,
    sex = "female",
    have_dyspnoea = "no",
    have_chest_pain = "yes",
    output = "percentage"
)

# 75 year old male with only dyspnoea
calculate_aha_2021_ptp(
    age = 75,
    sex = "male",
    have_dyspnoea = "yes",
    have_chest_pain = "no",
    output = "percentage"
)
}
